translate.storage.ini.inifile

Package translate :: Package storage :: Module ini :: Class inifile |
[hide private]
[frames] | no frames]

# Class inifile

source code

An INI file

Nested Classes | [hide private]
| UnitClass The class of units that will be instantiated and used by this class

Instance Methods | [hide private]
__init__(self, inputfile=None, unitclass=<class 'translate.storage.ini.iniunit'>, dialect=`'``default``'`) construct an INI file, optionally reading in from inputfile. | source code
__str__(self) Converts to a string representation that can be parsed back using parsestring(). | source code
parse(self, input) parse the given file or file source string | source code
Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `add_unit_to_index`, `addsourceunit`, `addunit`, `detect_encoding`, `findid`, `findunit`, `findunits`, `getids`, `getprojectstyle`, `getsourcelanguage`, `gettargetlanguage`, `getunits`, `isempty`, `makeindex`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setprojectstyle`, `setsourcelanguage`, `settargetlanguage`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
Inherited from `base.TranslationStore`: `parsefile`, `parsestring`

Class Variables | [hide private]
Inherited from `base.TranslationStore`: `Extensions`, `Mimetypes`, `Name`, `sourcelanguage`, `suggestions_in_format`, `targetlanguage` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, inputfile=None, unitclass=<class 'translate.storage.ini.iniunit'>, dialect=`'``default``'`) (Constructor) | source code
construct an INI file, optionally reading in from inputfile. Overrides: object.__init__

### __str__(self) (Informal representation operator) | source code
Converts to a string representation that can be parsed back using parsestring(). Overrides: object.__str__ (inherited documentation)

### parse(self, input) | source code
parse the given file or file source string Overrides: base.TranslationStore.parse